fn main() {
    windows::build!(
        Windows::Win32::UI::WindowsAndMessaging::*,
        Windows::Win32::UI::HiDpi::*,
        Windows::Win32::Graphics::Gdi::{
            MonitorFromPoint,
            GetMonitorInfoW,
            EnumDisplayMonitors,
            BeginPaint,
            EndPaint,
            GetStockObject,
            RedrawWindow,
            MONITORINFO,
            PAINTSTRUCT,
        },
        Windows::Win32::UI::KeyboardAndMouseInput::*,
        Windows::Win32::System::LibraryLoader::{
            GetModuleHandleW,
        },
        Windows::Win32::System::Memory::{
            LocalFree,
        },
        Windows::Win32::Foundation::{
            POINT,
            SIZE,
            RECT,
            WPARAM,
            LPARAM,
            BOOL,
            PSTR,
            PWSTR,
            HWND,
            HINSTANCE,
            CloseHandle,
        },
        Windows::Win32::System::Diagnostics::Debug::{
            FormatMessageW,
            GetLastError,
        },
        Windows::Win32::Globalization::*,
        Windows::Win32::UI::Shell::{
            DragAcceptFiles,
            DragQueryFileW,
            DragQueryPoint,
            DragFinish
        },
        Windows::Win32::UI::Controls::WM_MOUSELEAVE,
        Windows::Win32::Storage::FileSystem::*,
        Windows::Win32::Devices::HumanInterfaceDevice::*,
    );
}
